emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
From: Christopher Suckling <suckling.list@googlemail.com>
To: Carsten Dominik <carsten.dominik@gmail.com>
Cc: emacs-orgmode emacs-orgmode <emacs-orgmode@gnu.org>,
	Christopher Suckling <suckling.list@googlemail.com>
Subject: Re: Problem with org-mac-message.el
Date: Sun, 5 Apr 2009 22:43:52 +0100	[thread overview]
Message-ID: <8103B75E-48DB-46AB-A43F-6905A9F0B9D4@gmail.com> (raw)
In-Reply-To: <25FA0450-9B9A-42E0-93AF-14E53F3CB076@gmail.com>

[-- Attachment #1: Type: text/plain, Size: 691 bytes --]


On 4 Apr 2009, at 11:33, Carsten Dominik wrote:

> Hi Christopher,
>
> I have applied the patch, thanks.
>
> Also I made the following modification:
>
> The new function is defined as org-mac-message-insert-selected,
> and then the old name org-mac-message-insert-link is introduced
> as an alias.  So you get your consisten function naming, and
> compatibility as well.
>
> I believe the file commentary may not be fully correct anymore,
> it still mentions the old function names.  I have already pushed the
> new version, if you fix the commentary, please diff against that new  
> version.

Thanks, Carsten.

Here's the fixed commentary. Changes to Worg have been pushed.

Christopher


[-- Attachment #2: org-mac-message.patch --]
[-- Type: application/octet-stream, Size: 2063 bytes --]

diff --git a/lisp/org-mac-message.el b/lisp/org-mac-message.el
index fb71ebd..3ea55d8 100644
--- a/lisp/org-mac-message.el
+++ b/lisp/org-mac-message.el
@@ -1,4 +1,4 @@
 ;;; org-mac-message.el --- Links to Apple Mail messages from within Org-mode
 
 ;; Copyright (C) 2008, 2009 Free Software Foundation, Inc.
 
@@ -24,18 +24,18 @@
 ;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 ;; This file implements links to Apple Mail messages from within Org-mode.
 ;; Org-mode does not load this module by default - if you would actually like
 ;; this to happen then configure the variable `org-modules'.
 
 ;; If you would like to create links to all flagged messages in an
 ;; Apple Mail account, please customize the variable
 ;; org-mac-mail-account and then call one of the following functions:
 
-;; (org-mac-create-flagged-mail) copies a formatted list of links to
-;; the kill ring.
+;; (org-mac-message-insert-selected) inserts at point links to any
+;; messages selected in Mail.app.
 
-;; (org-mac-insert-flagged-mail) searches within an org-mode buffer
+;; (org-mac-message-insert-flagged) searches within an org-mode buffer
 ;; for a specific heading, creating it if it doesn't exist. Any
 ;; message:// links within the first level of the heading are deleted
 ;; and replaced with links to flagged messages.
@@ -160,9 +160,9 @@ of it."
   (message "Messages copied to kill-ring"))
 
 (defun org-mac-message-insert-selected ()
-  "Insert a link to the messages currently selected in Apple Mail.
+  "Insert a link to the messages currently selected in Mail.app.
 This will use applescript to get the message-id and the subject of the
-active mail in AppleMail and make a link out of it."
+active mail in Mail.app and make a link out of it."
   (interactive)
   (org-mac-message-get-links "s")
   (yank))
@@ -1,4 +1,4 @@
-;;; org-mac-message.el --- Links to Apple Mail messages from within Org-mode
+;;; org-mac-message.el --- Links to Apple Mail.app messages from within Org-mode
 
 ;; Copyright (C) 2008, 2009 Free Software Foundation, Inc.
@@ -24,18 +24,18 @@
 
 ;;; Commentary:
-;; This file implements links to Apple Mail messages from within Org-mode.
+;; This file implements links to Apple Mail.app messages from within Org-mode.
 ;; Org-mode does not load this module by default - if you would actually like
 ;; this to happen then configure the variable `org-modules'.
@@ -24,18 +24,18 @@
 
 ;; If you would like to create links to all flagged messages in an
-;; Apple Mail account, please customize the variable
+;; Mail.app account, please customize the variable
 ;; org-mac-mail-account and then call one of the following functions:
 

[-- Attachment #3: Type: text/plain, Size: 1 bytes --]



[-- Attachment #4: Type: text/plain, Size: 204 bytes --]

_______________________________________________
Emacs-orgmode mailing list
Remember: use `Reply All' to send replies to the list.
Emacs-orgmode@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-orgmode

  reply	other threads:[~2009-04-05 21:43 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2009-04-01 20:21 Problem with org-mac-message.el Ed Hirgelt
2009-04-03 14:49 ` Christopher Suckling
2009-04-03 16:58   ` Carsten Dominik
2009-04-04  7:18     ` Christopher Suckling
2009-04-04  8:25       ` Carsten Dominik
2009-04-04  8:52         ` Christopher Suckling
2009-04-04 10:33           ` Carsten Dominik
2009-04-05 21:43             ` Christopher Suckling [this message]
2009-04-06  4:44               ` Carsten Dominik

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://www.orgmode.org/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=8103B75E-48DB-46AB-A43F-6905A9F0B9D4@gmail.com \
    --to=suckling.list@googlemail.com \
    --cc=carsten.dominik@gmail.com \
    --cc=emacs-orgmode@gnu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).